@@ -22,7 +22,7 @@ if [[ $# -ge 3 ]]; then
 else
 	# Standard build
 	DST_DIR=""
-	CMAKE_EXTRA_OPTIONS="-DWITH_OPENCL=1"
+	CMAKE_EXTRA_OPTIONS=""
 fi
 
 case "$VERSION_ID" in
@@ -64,8 +64,8 @@ sudo apt-get install -y -qq \
 	libncurses-dev \
 	libpci3 \
 	libpci-dev \
-	libglfw3 \
-	libglfw3-dev \
+	libglvnd0 \
+	libglvnd-dev \
 	libvulkan-dev \
 	libglvnd-dev \
 	opencl-headers \
