@@ -39,14 +39,12 @@
 #include "options.hpp"
 #include "util.hpp"
 #include "data.hpp"
-#include "core.hpp"
-#include "daemon.h"
-#include "daemon_client.hpp"
+#include "core/core.hpp"
+#include "daemon/daemon.h"
+#include "daemon/client.hpp"
 
 #define LOG_FILE "/tmp/cpu-x.log"
 
-bool __sigabrt_received = false;
-
 
 /************************* Options-related functions *************************/
 
@@ -158,9 +156,9 @@ static void version(bool full_header)
 		{ HAS_NCURSES,     "NCURSES",     NCURSES_VERSION     },
 		{ HAS_LIBCPUID,    "LIBCPUID",    LIBCPUID_VERSION    },
 		{ HAS_LIBPCI,      "LIBPCI",      LIBPCI_VERSION      },
-		{ HAS_LIBGLFW,     "LIBGLFW",     LIBGLFW_VERSION     },
-		{ HAS_Vulkan,      "VULKAN",      Vulkan_VERSION      },
-		{ HAS_OpenCL,      "OPENCL",      OpenCL_VERSION      },
+		{ HAS_LIBEGL,      "LIBEGL",      LIBEGL_VERSION      },
+		{ HAS_VULKAN,      "VULKAN",      VULKAN_VERSION      },
+		{ HAS_OPENCL,      "OPENCL",      OPENCL_VERSION      },
 		{ HAS_LIBPROC2,    "LIBPROC2",    LIBPROC2_VERSION    },
 		{ HAS_LIBPROCPS,   "LIBPROCPS",   LIBPROCPS_VERSION   },
 		{ HAS_LIBSTATGRAB, "LIBSTATGRAB", LIBSTATGRAB_VERSION },
@@ -457,7 +455,6 @@ static void sighandler_fatal(int signum)
 /* Action on SIGABRT */
 static void sighandler_abrt(int signum)
 {
-	__sigabrt_received = true;
 	common_sighandler(signum, false);
 }
 
